@@ -1,8 +1,10 @@
 package Bundle::SPOPS;
 
+# $Id$
+
 use strict;
 
-$Bundle::SPOPS::VERSION = '1.02';
+$Bundle::SPOPS::VERSION = '1.03';
 
 1;
 
@@ -24,7 +26,7 @@ Data::Dumper
 
 Date::Calc (4.3)
 
-SPOPS
+SPOPS::Configure
 
 =head1 DESCRIPTION
 
@@ -34,6 +36,20 @@ going to need at least L<DBI> plus one or more of the supported DBD
 drivers (like L<DBD::mysql>, L<DBD::Sybase>, L<DBD::ASAny>). You can
 also currently use SPOPS with L<GDBM_File>.
 
+=head1 MORE INFORMATION
+
+Information on the web about this module is found with OpenInteract,
+even though SPOPS is self-contained and is very useful outside of
+OpenInteract.
+
+Sourceforge Project Home:
+
+ http://sourceforge.net/projects/openinteract/
+
+News, package repository and more information:
+
+ http://www.openinteract.org/
+
 =head1 AUTHOR
 
 Chris Winters <chris@cwinters.com>
